# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAllSchedules(BaseModel):
    get_all_schedules: Optional[
        List[Optional["GetAllSchedulesGetAllSchedules"]]
    ] = Field(alias="getAllSchedules")


class GetAllSchedulesGetAllSchedules(BaseModel):
    id: Optional[str]
    country_id: Optional[str] = Field(alias="countryId")
    country_name: Optional[str] = Field(alias="countryName")
    event_id: Optional[str] = Field(alias="eventId")
    event_id_wa: Optional[str] = Field(alias="eventId_WA")
    days: Optional[List[Optional["GetAllSchedulesGetAllSchedulesDays"]]]


class GetAllSchedulesGetAllSchedulesDays(BaseModel):
    day: Optional[int]
    date: Optional[Any]
    channels: Optional[List[Optional["GetAllSchedulesGetAllSchedulesDaysChannels"]]]


class GetAllSchedulesGetAllSchedulesDaysChannels(BaseModel):
    id: Optional[str] = Field(alias="_id")
    category: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_file_name: Optional[str] = Field(alias="logoFileName")
    title: Optional[str]
    time: Optional[List[Optional[str]]]


GetAllSchedules.model_rebuild()
GetAllSchedulesGetAllSchedules.model_rebuild()
GetAllSchedulesGetAllSchedulesDays.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSearchResults(BaseModel):
    get_search_results: Optional["GetSearchResultsGetSearchResults"] = Field(
        alias="getSearchResults"
    )


class GetSearchResultsGetSearchResults(BaseModel):
    items: Optional[List[Optional["GetSearchResultsGetSearchResultsItems"]]]


class GetSearchResultsGetSearchResultsItems(BaseModel):
    title: Optional[str]
    link: Optional[str]
    snippet: Optional[str]
    thumbnail: Optional[str]


GetSearchResults.model_rebuild()
GetSearchResultsGetSearchResults.model_rebuild()
